==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm5/lib/DataPieChartToolbarProvider.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { DomainChartToolbarProvider } from "./DomainChartToolbarProvider";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var DataPieChartToolbarProvider = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DataPieChartToolbarProvider, _super);
    function DataPieChartToolbarProvider() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.ad = null;
        return _this;
    }
    DataPieChartToolbarProvider.prototype.g = function (a, b) {
        var c = a;
        switch (b.name) {
            case "ShowGridlines":
                {
                    var d = b;
                    d.isChecked = c.afu != null;
                }
                break;
        }
    };
    DataPieChartToolbarProvider.prototype.z = function (a, b, c, d) {
        var e = a;
        switch (b) {
            case "AngleAxisMajorStroke":
                this.h("ShowGridlines", 2, a.afu != null);
                break;
        }
    };
    DataPieChartToolbarProvider.prototype.p = function (a, b) {
        var c = a;
        if (this.c(b, "ShowGridlines")) {
            if (c.afu == null) {
                if (this.ad != null) {
                    c.afu = this.ad;
                }
                else {
                    c.afu = c.dataChart.aai;
                }
            }
        }
        else {
            if (c.afu != null) {
                this.ad = c.afu;
                c.afu = null;
            }
        }
    };
    DataPieChartToolbarProvider.$t = markType(DataPieChartToolbarProvider, 'DataPieChartToolbarProvider', DomainChartToolbarProvider.$);
    return DataPieChartToolbarProvider;
}(DomainChartToolbarProvider));
export { DataPieChartToolbarProvider };

==> igniteui-react-charts-18.7.5-beta.0.tgz: package/esm5/lib/DataPieChartToolbarProvider.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { DomainChartToolbarProvider } from "./DomainChartToolbarProvider";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var DataPieChartToolbarProvider = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DataPieChartToolbarProvider, _super);
    function DataPieChartToolbarProvider() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.ae = null;
        return _this;
    }
    DataPieChartToolbarProvider.prototype.h = function (a, b) {
        var c = a;
        switch (b.name) {
            case "ShowGridlines":
                {
                    var d = b;
                    d.isChecked = c.af9 != null;
                }
                break;
        }
    };
    DataPieChartToolbarProvider.prototype.aa = function (a, b, c, d) {
        var e = a;
        switch (b) {
            case "AngleAxisMajorStroke":
                this.i("ShowGridlines", 2, a.af9 != null);
                break;
        }
    };
    DataPieChartToolbarProvider.prototype.q = function (a, b) {
        var c = a;
        if (this.d(b, "ShowGridlines")) {
            if (c.af9 == null) {
                if (this.ae != null) {
                    c.af9 = this.ae;
                }
                else {
                    c.af9 = c.dataChart.aap;
                }
            }
        }
        else {
            if (c.af9 != null) {
                this.ae = c.af9;
                c.af9 = null;
            }
        }
    };
    DataPieChartToolbarProvider.$t = markType(DataPieChartToolbarProvider, 'DataPieChartToolbarProvider', DomainChartToolbarProvider.$);
    return DataPieChartToolbarProvider;
}(DomainChartToolbarProvider));
export { DataPieChartToolbarProvider };
